# -*- coding: utf-8 -*-

from django.utils.translation import ugettext_lazy as _
from django.core.urlresolvers import reverse

import admin_tools
from admin_tools.dashboard import modules, register, AppIndexDashboard

from jmb.core.admin import dashboard as jmb_dashboard


class DefaultDashboard(modules.Group):
    def __init__(self, **kwargs):

        kwargs = {
            'title': _("Stats"),
            'display': "tabs",
            'children': [
                Models(),
            ]
        }
        super(DefaultDashboard, self).__init__(**kwargs)


class StatsDashboard(modules.Group):
    def __init__(self, **kwargs):

        kwargs = {
            'title': _("Stats"),
            'display': "tabs",
            'children': [
                Models(),
                Graph(),
            ]
        }
        super(StatsDashboard, self).__init__(**kwargs)


class Models(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs = {
            'title': _("Main Models"),
            'models': ('tre.stats.models.*',),
        }
        super(Models, self).__init__(**kwargs)


class Graph(modules.LinkList):
    def __init__(self, **kwargs):
        kwargs = {
            'title': _("Graphics"),
            'children': [
                [_('Overview'), reverse('admin:stats_request_overview')]
            ],
        }
        super(Graph, self).__init__(**kwargs)


class OtherModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs = {
            'title': _("Others"),
            'models': (),
        }
        super(OtherModels, self).__init__(**kwargs)

class DefaultAppDashboard(AppIndexDashboard):
    def __init__(self, app_title, models, **kwargs):
        AppIndexDashboard.__init__(self, app_title, models, **kwargs)
        self.columns = 3

    def init_with_context(self, context):
        request = context['request']

        # Registered dashboards
        self.children.append(
            DefaultDashboard(),
        )

# Used in /admin
jmb_dashboard.register_group(StatsDashboard, 'tre.stats')
# Used in /admin/Stats
admin_tools.dashboard.register(DefaultAppDashboard, 'tre.stats')
